==> speech-analytic-testing_3.5.2_database.tar.gz: database/mssql/procedures/SaveEvaluationTipification.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[SaveEvaluationTipification] (
	@VCC VARCHAR(50) = NULL,
	@AbilityId VARCHAR(50) = NULL,
	@ScoreId VARCHAR(50) = NULL,
	@ID VARCHAR(50) = NULL,
	@IsChecked BIT = 0,
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionId VARCHAR(250) = NULL,
	@AuditorId VARCHAR(50) = NULL,
	@UserId VARCHAR(50) = NULL
) AS
BEGIN
	SET NOCOUNT ON
	-- EL PRESENTE SP TIENE LA FINALIDAD DE RESPALDAR LOS RESULTADOS GENERADOS EN LA PARTE AUTOMATICA DEL PLAN MIXTO

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
        
		-- INICIAMOS LA TRANSACCION
		BEGIN TRANSACTION

		-- ACTUALIZAMOS EL REGISTRO EN CASO EXISTA
		UPDATE [dbo].[EvaluationTipification]
			SET [IsChecked] = @IsChecked,
				[AuditorId] = @AuditorId
			WHERE [VCC] = @VCC 
				AND [EvaluationPlanId] = @EvaluationPlanId
				AND [InteractionId] = @InteractionId
				AND [AuditorId] = @AuditorId
				AND [AbilityId] = @AbilityId
				AND [ScoreId] = @ScoreId
				AND [ID] = @ID

		-- EN CASO NO HAYA HABIDO NINGUNA ACTUALIZACION, INSERTAMOS EL REGISTRO
		IF @@ROWCOUNT = 0
		BEGIN
			INSERT INTO [dbo].[EvaluationTipification] (
				[VCC], [AbilityId], [ScoreId], [ID], [IsChecked], 
				[CreatedDate], [CreatedByUserId], [EvaluationPlanId], [InteractionId], [AuditorId]
			)
			VALUES (
				@VCC, @AbilityId, @ScoreId, @ID, @IsChecked, GETUTCDATE(),
				@UserId, @EvaluationPlanId, @InteractionId, @AuditorId
			)

		END
		
		SELECT 1 AS 'result'

		-- COMPLETAMOS LA TRANSACCION
		COMMIT TRANSACTION

    END TRY
    BEGIN CATCH
        IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH
	
	
    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_3.6.0_database.tar.gz: database/mssql/procedures/SaveEvaluationTipification.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[SaveEvaluationTipification] (
	@VCC VARCHAR(50) = NULL,
	@AbilityId VARCHAR(50) = NULL,
	@ScoreId VARCHAR(50) = NULL,
	@ID VARCHAR(50) = NULL,
	@IsChecked BIT = 0,
	@Comment VARCHAR(250) = NULL,
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionId VARCHAR(250) = NULL,
	@AuditorId VARCHAR(50) = NULL,
	@UserId VARCHAR(50) = NULL
) AS
BEGIN
	SET NOCOUNT ON
	-- EL PRESENTE SP TIENE LA FINALIDAD DE RESPALDAR LOS RESULTADOS GENERADOS EN LA PARTE AUTOMATICA DEL PLAN MIXTO

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
        
		-- INICIAMOS LA TRANSACCION
		BEGIN TRANSACTION

		-- ACTUALIZAMOS EL REGISTRO EN CASO EXISTA
		UPDATE [dbo].[EvaluationTipification]
			SET [IsChecked] = @IsChecked,
				[Comment] = @Comment,
				[AuditorId] = @AuditorId
			WHERE [VCC] = @VCC 
				AND [EvaluationPlanId] = @EvaluationPlanId
				AND [InteractionId] = @InteractionId
				AND [AuditorId] = @AuditorId
				AND [AbilityId] = @AbilityId
				AND [ScoreId] = @ScoreId
				AND [ID] = @ID

		-- EN CASO NO HAYA HABIDO NINGUNA ACTUALIZACION, INSERTAMOS EL REGISTRO
		IF @@ROWCOUNT = 0
		BEGIN
			INSERT INTO [dbo].[EvaluationTipification] (
				[VCC], [AbilityId], [ScoreId], [ID], [IsChecked], 
				[Comment], [CreatedDate], [CreatedByUserId], [EvaluationPlanId], [InteractionId], 
				[AuditorId]
			)
			VALUES (
				@VCC, @AbilityId, @ScoreId, @ID, @IsChecked, 
				@Comment, GETUTCDATE(), @UserId, @EvaluationPlanId, @InteractionId, 
				@AuditorId
			)

		END
		
		SELECT 1 AS 'result'

		-- COMPLETAMOS LA TRANSACCION
		COMMIT TRANSACTION

    END TRY
    BEGIN CATCH
        IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH
	
	
    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
